@@ -82,14 +82,17 @@ impl AsP2pAgentStoreConExt for crate::db::PConn {
 }
 
 /// Put an AgentInfoSigned record into the p2p_store
-pub async fn p2p_put(db: &DbWrite, signed: &AgentInfoSigned) -> DatabaseResult<()> {
+pub async fn p2p_put(
+    db: &DbWrite<DbKindP2pAgentStore>,
+    signed: &AgentInfoSigned,
+) -> DatabaseResult<()> {
     let record = P2pRecord::from_signed(signed)?;
     db.async_commit(move |txn| tx_p2p_put(txn, record)).await
 }
 
 /// Put an iterator of AgentInfoSigned records into the p2p_store
 pub async fn p2p_put_all(
-    db: &DbWrite,
+    db: &DbWrite<DbKindP2pAgentStore>,
     signed: impl Iterator<Item = &AgentInfoSigned>,
 ) -> DatabaseResult<()> {
     let mut records = Vec::new();
@@ -133,7 +136,7 @@ fn tx_p2p_put(txn: &mut Transaction, record: P2pRecord) -> DatabaseResult<()> {
 }
 
 /// Prune all expired AgentInfoSigned records from the p2p_store
-pub async fn p2p_prune(db: &DbWrite) -> DatabaseResult<()> {
+pub async fn p2p_prune(db: &DbWrite<DbKindP2pAgentStore>) -> DatabaseResult<()> {
     db.async_commit(move |txn| {
         let now = std::time::SystemTime::now()
             .duration_since(std::time::SystemTime::UNIX_EPOCH)
